==> haskell-prettyprinter-ansi-terminal-1.1.3-385-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-IaiwJGU5h7gDXHX3Nxd5K0
key:                  prettyprinter-ansi-terminal-1.1.3-IaiwJGU5h7gDXHX3Nxd5K0
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  27bb21cabe5ea3b27307c5b62735acf1
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-IaiwJGU5h7gDXHX3Nxd5K0
depends:
    ansi-terminal-1.0.2-7enoCfAnx2SGJDVGgMW6rt base-4.17.2.1
    prettyprinter-1.7.1-80F1dUtwFWzDp5CT3ZZVKz text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.3-389-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-zpJIE64fpCIqSqesY8J9j
key:                  prettyprinter-ansi-terminal-1.1.3-zpJIE64fpCIqSqesY8J9j
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  5a5f192c2ff01512ac42dd3eb11f1e4a
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-zpJIE64fpCIqSqesY8J9j
depends:
    ansi-terminal-1.0.2-vFVvoY6zrCCEYOqozRT68 base-4.17.2.1
    prettyprinter-1.7.1-AIJZZXuo91NCViNpmKNzcQ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
